@@ -3,20 +3,8 @@
  *
  * Author: Jorn Baayen <jorn@openedhand.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -57,7 +45,7 @@ typedef struct _GUPnPControlPointPrivate GUPnPControlPointPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GUPnPControlPoint,
                             gupnp_control_point,
-                            GSSDP_TYPE_RESOURCE_BROWSER);
+                            GSSDP_TYPE_RESOURCE_BROWSER)
 
 enum {
         PROP_0,
