@@ -3,20 +3,8 @@
  *
  * Author: Jens Georg <mail@jensge.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -96,7 +84,7 @@ struct _GUPnPLinuxContextManager {
 
 G_DEFINE_TYPE_WITH_PRIVATE (GUPnPLinuxContextManager,
                             gupnp_linux_context_manager,
-                            GUPNP_TYPE_CONTEXT_MANAGER);
+                            GUPNP_TYPE_CONTEXT_MANAGER)
 
 typedef enum {
         /* Interface is up */
